@@ -67,6 +67,8 @@
 #' # needed for "state" database (unless you execute library(maps))
 #' data(countyMapEnv, package = "maps")
 #' plot(out, usemap = TRUE, mapargs = mapargs)
+#' # extract detected clusteers
+#' clusters(out)
 #'
 #' # a second example to match the results of Waller and Gotway (2005)
 #' # in chapter 7 of their book (pp. 220-221).
@@ -120,6 +122,11 @@ scan.test = function(coords, cases, pop,
   if (type == "poisson") {
     ein = nn.cumsum(nn, ex)
     eout = sum(ex) - ein
+    # correct for the situation when the expected number of cases
+    # is not the same as the observed number of cases
+    mult = ty / sum(ex)
+    ein = ein * mult
+    eout = eout * mult
     popin = NULL
     popout = NULL
     tpop = NULL
